import React from 'react';
import { RendererFunction } from 'react-native-render-html';
import extractHtmlIframeProps from './extractHtmlIframeProps';
import HTMLIframe from './HTMLIframe';

/**
 * The renderer function for the iframe element. This renderer is fully
 * scalable, and will adjust to `contentWidth` and `computeEmbeddedMaxWidth`.
 * It also features `onLinkPress`.
 *
 * @param htmlAttribs - HTML attributes of the element.
 * @param children - The children (ignored)
 * @param convertedCSSStyles - Inline styles
 * @param passProps - Passed props from the root component.
 *
 * @public
 */
const iframe: RendererFunction<any> = function iframe(
  htmlAttribs,
  children,
  convertedCSSStyles,
  passProps
) {
  const props = extractHtmlIframeProps(
    htmlAttribs,
    convertedCSSStyles,
    passProps
  );

  return props.WebView ? React.createElement(HTMLIframe, props) : null;
};

export default iframe;
