import { ComponentType } from 'react';
import { ContainerProps } from 'react-native-render-html';
import { HtmlAttributesDictionary } from 'react-native-render-html';
import { PassProps } from 'react-native-render-html';
import { default as React_2 } from 'react';
import { RendererFunction } from 'react-native-render-html';
import { StyleProp } from 'react-native';
import { ViewStyle } from 'react-native';

/**
 * Extract props for the HTMLIframe component from renderer function arguments.
 * This function is especially usefull for custom iframe renderers.
 *
 * @param htmlAttribs - The HTML node attributes.
 * @param convertedCSSStyles - Converted inline styles.
 * @param passProps - Passed props.
 *
 * @public
 */
export declare function extractHtmlIframeProps(htmlAttribs: HtmlAttributesDictionary, convertedCSSStyles: StyleProp<any>, passProps: PassProps<any>): HTMLIframeProps;

/**
 * A component to render iframes in react-native-render-html.
 *
 * @public
 */
export declare function HTMLIframe({ WebView, webViewProps: userWebViewProps, source, style, onLinkPress, htmlAttribs, scaleFactor, autoscale }: HTMLIframeProps): React_2.ReactElement<any, string | ((props: any) => React_2.ReactElement<any, string | any | (new (props: any) => React_2.Component<any, any, any>)> | null) | (new (props: any) => React_2.Component<any, any, any>)>;

/**
 * Configuration options for the HTMLIframe component.
 * You can pass those options through `renderersProps.iframe`
 * HTML prop.
 *
 * @public
 */
export declare interface HTMLIframeConfig {
    /**
     * When the iframe attribute width is wider than the contentWidth, scales
     * down the viewport so that it doesn't overflows horizontally.
     *
     * @defaultvalue true
     */
    autoscale: boolean;
}

/**
 * Props for the HTMLIframe component.
 *
 * @public
 */
export declare interface HTMLIframeProps<WebViewProps = any> extends HTMLIframeConfig {
    /**
     * The `WebView` Component you wish to use.
     */
    WebView: ComponentType<WebViewProps>;
    webViewProps?: WebViewProps;
    source: {
        uri?: string;
        html?: string;
    };
    style: StyleProp<ViewStyle>;
    onLinkPress?: ContainerProps['onLinkPress'];
    htmlAttribs: HtmlAttributesDictionary;
    /**
     * When autoscale is enabled, scales the WebView zoom level to make sure the
     * viewport fits contentWidth.
     */
    scaleFactor: number;
}

/**
 * The renderer function for the iframe element. This renderer is fully
 * scalable, and will adjust to `contentWidth` and `computeEmbeddedMaxWidth`.
 * It also features `onLinkPress`.
 *
 * @param htmlAttribs - HTML attributes of the element.
 * @param children - The children (ignored)
 * @param convertedCSSStyles - Inline styles
 * @param passProps - Passed props from the root component.
 *
 * @public
 */
declare const iframe: RendererFunction<any>;
export default iframe;

export { }
